"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_1 = require("graphql");
const graphql_toolkit_1 = require("graphql-toolkit");
const path_1 = require("path");
const graphql_tag_1 = require("graphql-tag");
const visitor_1 = require("./visitor");
exports.plugin = (schema, documents, config) => {
    const visitor = new visitor_1.TsMongoVisitor(schema, config);
    const printedSchema = graphql_toolkit_1.printSchemaWithDirectives(schema);
    const astNode = graphql_1.parse(printedSchema);
    const visitorResult = graphql_1.visit(astNode, { leave: visitor });
    const header = visitor.objectIdImport;
    return [header, ...visitorResult.definitions.filter(d => typeof d === 'string')].join('\n');
};
var Directives;
(function (Directives) {
    Directives["ID"] = "id";
    Directives["ENTITY"] = "entity";
    Directives["ABSTRACT_ENTITY"] = "abstractEntity";
    Directives["UNION"] = "union";
    Directives["LINK"] = "link";
    Directives["COLUMN"] = "column";
    Directives["EMBEDDED"] = "embedded";
    Directives["MAP"] = "map";
})(Directives = exports.Directives || (exports.Directives = {}));
exports.DIRECTIVES = graphql_tag_1.default `
  directive @${Directives.UNION}(discriminatorField: String, additionalFields: [AdditionalEntityFields]) on UNION
  directive @${Directives.ABSTRACT_ENTITY}(discriminatorField: String!, additionalFields: [AdditionalEntityFields]) on INTERFACE
  directive @${Directives.ENTITY}(embedded: Boolean, additionalFields: [AdditionalEntityFields]) on OBJECT
  directive @${Directives.COLUMN}(overrideType: String) on FIELD_DEFINITION
  directive @${Directives.ID} on FIELD_DEFINITION
  directive @${Directives.LINK} on FIELD_DEFINITION
  directive @${Directives.EMBEDDED} on FIELD_DEFINITION
  directive @${Directives.MAP}(path: String!) on FIELD_DEFINITION
  # Inputs
  input AdditionalEntityFields {
    path: String
    type: String
  }
`;
exports.addToSchema = exports.DIRECTIVES;
exports.validate = async (schema, documents, config, outputFile) => {
    if (path_1.extname(outputFile) !== '.ts') {
        throw new Error(`Plugin "typescript-mongodb" requires extension to be ".ts"!`);
    }
};
//# sourceMappingURL=index.js.map